Package 'epitemplate'

Title: pkgdown Template for EPI R Packages
Description: A pkgdown template package that provides consistent styling and layout for R package documentation sites maintained by the Economic Policy Institute. Use this package as the template in your pkgdown configuration to apply EPI branding and defaults.
Authors: Ben Zipperer [aut, cre], Economic Policy Institute [cph, fnd]
Maintainer: Ben Zipperer <[email protected]>
License: MIT + file LICENSE
Version: 0.2.0
Built: 2026-05-15 08:36:57 UTC
Source: https://github.com/economic/epitemplate

Help Index


Test function for template preview

Description

This function exists solely to generate a reference page for visually testing the epitemplate pkgdown theme. It has no real functionality.

Usage

test(x = 1:3)

Arguments

x

A numeric value.

Value

A data frame with columns x, x_squared, and x_cubed.

Another section

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Turpis massa tincidunt dui ut ornare lectus. In est ante in nibh. Eu sem integer vitae justo eget. Massa placerat duis ultricies lacus sed turpis. Etiam sit amet nisl purus in mollis nunc sed id. Porta non pulvinar neque laoreet suspendisse interdum consectetur.

Another subsection

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

Examples

test()
test(1:5)